# Security Policy

## Supported Versions

Since we are in pre-release, we support any version that starts with 0.
| Version | Supported          |
| ------- | ------------------ |
| 0.x.x   | :white_check_mark: |


## Reporting a Vulnerability

If you find a vulnerability, make sure to open an issue or a pull request to patch it or report the vulnerability to us as **SOON AS POSSIBLE.**
You can expect updates on your issue/pull request every few hours or days, depending on whether I'm online or not.
If it is **CRITICAL**, report it to us privately.
